@@ -4,6 +4,7 @@ from __future__ import annotations
 
 import contextlib
 import errno
+import http.client
 import io
 import os
 import os.path
@@ -11,28 +12,20 @@ import select
 import shutil
 import socket
 import ssl
-import sys
 import tempfile
-import time
+import threading
 import typing
 import zlib
 from collections import OrderedDict
 from pathlib import Path
-from test import (
-    LONG_TIMEOUT,
-    SHORT_TIMEOUT,
-    notSecureTransport,
-    notWindows,
-    requires_ssl_context_keyfile_password,
-    resolvesLocalhostFQDN,
-)
+from test import LONG_TIMEOUT, SHORT_TIMEOUT, notWindows, resolvesLocalhostFQDN
 from threading import Event
 from unittest import mock
 
 import pytest
 import trustme
 
-from dummyserver.server import (
+from dummyserver.socketserver import (
     DEFAULT_CA,
     DEFAULT_CERTS,
     encrypt_key_pem,
@@ -56,7 +49,7 @@ from urllib3.util import ssl_, ssl_wrap_socket
 from urllib3.util.retry import Retry
 from urllib3.util.timeout import Timeout
 
-from .. import LogRecorder, has_alpn
+from .. import LogRecorder
 
 if typing.TYPE_CHECKING:
     from _typeshed import StrOrBytesPath
@@ -115,9 +108,6 @@ class TestSNI(SocketDummyServerTestCase):
 
 class TestALPN(SocketDummyServerTestCase):
     def test_alpn_protocol_in_first_request_packet(self) -> None:
-        if not has_alpn():
-            pytest.skip("ALPN-support not available")
-
         done_receiving = Event()
         self.buf = b""
 
@@ -329,11 +319,9 @@ class TestClientCerts(SocketDummyServerTestCase):
                 done_receiving.set()
             done_receiving.set()
 
-    @requires_ssl_context_keyfile_password()
     def test_client_cert_with_string_password(self) -> None:
         self.run_client_cert_with_password_test("letmein")
 
-    @requires_ssl_context_keyfile_password()
     def test_client_cert_with_bytes_password(self) -> None:
         self.run_client_cert_with_password_test(b"letmein")
 
@@ -385,7 +373,6 @@ class TestClientCerts(SocketDummyServerTestCase):
 
             assert len(client_certs) == 1
 
-    @requires_ssl_context_keyfile_password()
     def test_load_keyfile_with_invalid_password(self) -> None:
         assert ssl_.SSLContext is not None
         context = ssl_.SSLContext(ssl_.PROTOCOL_SSLv23)
@@ -396,9 +383,6 @@ class TestClientCerts(SocketDummyServerTestCase):
                 password=b"letmei",
             )
 
-    # For SecureTransport, the validation that would raise an error in
-    # this case is deferred.
-    @notSecureTransport()
     def test_load_invalid_cert_file(self) -> None:
         assert ssl_.SSLContext is not None
         context = ssl_.SSLContext(ssl_.PROTOCOL_SSLv23)
@@ -970,7 +954,11 @@ class TestSocketClosing(SocketDummyServerTestCase):
             assert response.connection is None
 
     def test_socket_close_socket_then_file(self) -> None:
-        def consume_ssl_socket(listener: socket.socket) -> None:
+        quit_event = threading.Event()
+
+        def consume_ssl_socket(
+            listener: socket.socket,
+        ) -> None:
             try:
                 with listener.accept()[0] as sock, original_ssl_wrap_socket(
                     sock,
@@ -979,11 +967,11 @@ class TestSocketClosing(SocketDummyServerTestCase):
                     certfile=DEFAULT_CERTS["certfile"],
                     ca_certs=DEFAULT_CA,
                 ) as ssl_sock:
-                    consume_socket(ssl_sock)
+                    consume_socket(ssl_sock, quit_event=quit_event)
             except (ConnectionResetError, ConnectionAbortedError, OSError):
                 pass
 
-        self._start_server(consume_ssl_socket)
+        self._start_server(consume_ssl_socket, quit_event=quit_event)
         with socket.create_connection(
             (self.host, self.port)
         ) as sock, contextlib.closing(
@@ -993,13 +981,13 @@ class TestSocketClosing(SocketDummyServerTestCase):
         ) as f:
             ssl_sock.close()
             f.close()
-            # SecureTransport is supposed to raise OSError but raises
-            # ssl.SSLError when closed because ssl_sock.context is None
-            with pytest.raises((OSError, ssl.SSLError)):
+            with pytest.raises(OSError):
                 ssl_sock.sendall(b"hello")
             assert ssl_sock.fileno() == -1
 
     def test_socket_close_stays_open_with_makefile_open(self) -> None:
+        quit_event = threading.Event()
+
         def consume_ssl_socket(listener: socket.socket) -> None:
             try:
                 with listener.accept()[0] as sock, original_ssl_wrap_socket(
@@ -1009,11 +997,11 @@ class TestSocketClosing(SocketDummyServerTestCase):
                     certfile=DEFAULT_CERTS["certfile"],
                     ca_certs=DEFAULT_CA,
                 ) as ssl_sock:
-                    consume_socket(ssl_sock)
+                    consume_socket(ssl_sock, quit_event=quit_event)
             except (ConnectionResetError, ConnectionAbortedError, OSError):
                 pass
 
-        self._start_server(consume_ssl_socket)
+        self._start_server(consume_ssl_socket, quit_event=quit_event)
         with socket.create_connection(
             (self.host, self.port)
         ) as sock, contextlib.closing(
@@ -1150,6 +1138,27 @@ class TestProxyManager(SocketDummyServerTestCase):
                     retries=False,
                 )
 
+    def test_tunnel_sets_http_11_alpn(self) -> None:
+        done_receiving = Event()
+        self.buf = b""
+
+        def socket_handler(listener: socket.socket) -> None:
+            sock = listener.accept()[0]
+
+            self.buf = sock.recv(65536)  # We only accept one packet
+            done_receiving.set()  # let the test know it can proceed
+            sock.close()
+
+        self._start_server(socket_handler)
+        base_url = f"https://{self.host}:{self.port}"
+        with proxy_from_url(base_url) as proxy:
+            with pytest.raises(MaxRetryError):
+                proxy.request("GET", "https://localhost/")
+
+        done_receiving.wait()
+        assert b"http/1.1" in self.buf
+        assert b"h2" not in self.buf
+
     def test_connect_reconn(self) -> None:
         def proxy_ssl_one(listener: socket.socket) -> None:
             sock = listener.accept()[0]
@@ -1275,48 +1284,124 @@ class TestProxyManager(SocketDummyServerTestCase):
 
             errored.set()  # Avoid a ConnectionAbortedError on Windows.
 
-            assert type(e.value.reason) == ProxyError
+            assert type(e.value.reason) is ProxyError
             assert "Your proxy appears to only use HTTP and not HTTPS" in str(
                 e.value.reason
             )
 
+    def test_proxy_status_not_ok(self) -> None:
+        def http_socket_handler(listener: socket.socket) -> None:
+            sock = listener.accept()[0]
+            consume_socket(sock)
+            sock.send(b"HTTP/1.0 501 Not Implemented\r\nConnection: close\r\n\r\n")
+            sock.close()
+
+        self._start_server(http_socket_handler)
+        base_url = f"http://{self.host}:{self.port}"
+
+        with ProxyManager(base_url) as proxy:
+            with pytest.raises(MaxRetryError) as e:
+                proxy.request("GET", "https://example.com", retries=0)
+
+            assert type(e.value.reason) is ProxyError
+            assert e.value.reason.args[0] == "Unable to connect to proxy"
+            assert type(e.value.reason.args[1]) is OSError
+            assert (
+                str(e.value.reason.args[1])
+                == "Tunnel connection failed: 501 Not Implemented"
+            )
+
+    def test_early_eof_doesnt_cause_infinite_loop(self) -> None:
+        def http_socket_handler(listener: socket.socket) -> None:
+            sock = listener.accept()[0]
+            consume_socket(sock)
+            sock.send(b"HTTP/1.0 200 OK\r\n")
+            sock.close()
+
+        self._start_server(http_socket_handler)
+        base_url = f"http://{self.host}:{self.port}"
+
+        with ProxyManager(base_url) as proxy:
+            with pytest.raises(MaxRetryError):
+                proxy.request("GET", "https://example.com", retries=0)
+
+    def test_header_longer_than_maxline(self) -> None:
+        def http_socket_handler(listener: socket.socket) -> None:
+            sock = listener.accept()[0]
+            consume_socket(sock)
+            sock.send(
+                b"HTTP/1.0 200 OK\r\nThis-Header-Is-Too-Long: Way-Too-Long\r\n\r\n"
+            )
+            sock.close()
+
+        self._start_server(http_socket_handler)
+        base_url = f"http://{self.host}:{self.port}"
+
+        with mock.patch("http.client._MAXLINE", 17):
+            with ProxyManager(base_url) as proxy:
+                with pytest.raises(MaxRetryError) as e:
+                    proxy.request("GET", "https://example.com", retries=0)
+
+            assert type(e.value.reason) is ProtocolError
+            assert e.value.reason.args[0] == "Connection aborted."
+            assert type(e.value.reason.args[1]) is http.client.LineTooLong
+            assert (
+                str(e.value.reason.args[1])
+                == "got more than 17 bytes when reading header line"
+            )
+
+    def test_debuglevel(self, capsys: pytest.CaptureFixture[str]) -> None:
+        def http_socket_handler(listener: socket.socket) -> None:
+            sock = listener.accept()[0]
+            consume_socket(sock)
+            sock.send(b"HTTP/1.0 200 OK\r\nExample-Header: Example-Value\r\n\r\n")
+            sock.close()
+
+        self._start_server(http_socket_handler)
+        base_url = f"http://{self.host}:{self.port}"
+
+        with mock.patch("http.client.HTTPConnection.debuglevel", 1):
+            with ProxyManager(base_url) as proxy:
+                with pytest.raises(MaxRetryError):
+                    proxy.request("GET", "https://example.com", retries=0)
+
+        assert "header: Example-Header: Example-Value\r\n\n" in capsys.readouterr().out
+
 
 class TestSSL(SocketDummyServerTestCase):
     def test_ssl_failure_midway_through_conn(self) -> None:
         def socket_handler(listener: socket.socket) -> None:
-            sock = listener.accept()[0]
-            sock2 = sock.dup()
-            ssl_sock = original_ssl_wrap_socket(
-                sock,
-                server_side=True,
-                keyfile=DEFAULT_CERTS["keyfile"],
-                certfile=DEFAULT_CERTS["certfile"],
-                ca_certs=DEFAULT_CA,
-            )
+            with listener.accept()[0] as sock, sock.dup() as sock2:
+                ssl_sock = original_ssl_wrap_socket(
+                    sock,
+                    server_side=True,
+                    keyfile=DEFAULT_CERTS["keyfile"],
+                    certfile=DEFAULT_CERTS["certfile"],
+                    ca_certs=DEFAULT_CA,
+                )
 
-            buf = b""
-            while not buf.endswith(b"\r\n\r\n"):
-                buf += ssl_sock.recv(65536)
+                buf = b""
+                while not buf.endswith(b"\r\n\r\n"):
+                    buf += ssl_sock.recv(65536)
 
-            # Deliberately send from the non-SSL socket.
-            sock2.send(
-                b"HTTP/1.1 200 OK\r\n"
-                b"Content-Type: text/plain\r\n"
-                b"Content-Length: 2\r\n"
-                b"\r\n"
-                b"Hi"
-            )
-            sock2.close()
-            ssl_sock.close()
+                # Deliberately send from the non-SSL socket.
+                sock2.send(
+                    b"HTTP/1.1 200 OK\r\n"
+                    b"Content-Type: text/plain\r\n"
+                    b"Content-Length: 2\r\n"
+                    b"\r\n"
+                    b"Hi"
+                )
+                ssl_sock.close()
 
         self._start_server(socket_handler)
         with HTTPSConnectionPool(self.host, self.port, ca_certs=DEFAULT_CA) as pool:
             with pytest.raises(
-                SSLError, match=r"(wrong version number|record overflow)"
+                SSLError,
+                match=r"(wrong version number|record overflow|record layer failure)",
             ):
                 pool.request("GET", "/", retries=False)
 
-    @notSecureTransport()
     def test_ssl_read_timeout(self) -> None:
         timed_out = Event()
 
@@ -1371,19 +1456,21 @@ class TestSSL(SocketDummyServerTestCase):
                         certfile=DEFAULT_CERTS["certfile"],
                         ca_certs=DEFAULT_CA,
                     )
-                except (ssl.SSLError, ConnectionResetError):
-                    if i == 1:
-                        raise
-                    return
+                except (ssl.SSLError, ConnectionResetError, ConnectionAbortedError):
+                    pass
 
-                ssl_sock.send(
-                    b"HTTP/1.1 200 OK\r\n"
-                    b"Content-Type: text/plain\r\n"
-                    b"Content-Length: 5\r\n\r\n"
-                    b"Hello"
-                )
+                else:
+                    with ssl_sock:
+                        try:
+                            ssl_sock.send(
+                                b"HTTP/1.1 200 OK\r\n"
+                                b"Content-Type: text/plain\r\n"
+                                b"Content-Length: 5\r\n\r\n"
+                                b"Hello"
+                            )
+                        except (ssl.SSLEOFError, ConnectionResetError, BrokenPipeError):
+                            pass
 
-                ssl_sock.close()
                 sock.close()
 
         self._start_server(socket_handler)
@@ -1392,7 +1479,10 @@ class TestSSL(SocketDummyServerTestCase):
 
         def request() -> None:
             pool = HTTPSConnectionPool(
-                self.host, self.port, assert_fingerprint=fingerprint
+                self.host,
+                self.port,
+                assert_fingerprint=fingerprint,
+                cert_reqs="CERT_NONE",
             )
             try:
                 timeout = Timeout(connect=LONG_TIMEOUT, read=SHORT_TIMEOUT)
@@ -1405,10 +1495,21 @@ class TestSSL(SocketDummyServerTestCase):
 
         with pytest.raises(MaxRetryError) as cm:
             request()
-        assert isinstance(cm.value.reason, SSLError)
+        assert type(cm.value.reason) is SSLError
+        assert str(cm.value.reason) == (
+            "Fingerprints did not match. Expected "
+            '"a0c4a74600eda72dc0becb9a8cb607ca58ee745e", got '
+            '"728b554c9afc1e88a11cad1bb2e7cc3edbc8f98a"'
+        )
         # Should not hang, see https://github.com/urllib3/urllib3/issues/529
-        with pytest.raises(MaxRetryError):
+        with pytest.raises(MaxRetryError) as cm2:
             request()
+        assert type(cm2.value.reason) is SSLError
+        assert str(cm2.value.reason) == (
+            "Fingerprints did not match. Expected "
+            '"a0c4a74600eda72dc0becb9a8cb607ca58ee745e", got '
+            '"728b554c9afc1e88a11cad1bb2e7cc3edbc8f98a"'
+        )
 
     def test_retry_ssl_error(self) -> None:
         def socket_handler(listener: socket.socket) -> None:
@@ -1493,6 +1594,17 @@ class TestSSL(SocketDummyServerTestCase):
         context.load_default_certs = mock.Mock()
         context.options = 0
 
+        class MockSSLSocket:
+            def __init__(
+                self, sock: socket.socket, *args: object, **kwargs: object
+            ) -> None:
+                self._sock = sock
+
+            def close(self) -> None:
+                self._sock.close()
+
+        context.wrap_socket = MockSSLSocket
+
         with mock.patch("urllib3.util.ssl_.SSLContext", lambda *_, **__: context):
             self._start_server(socket_handler)
             with HTTPSConnectionPool(self.host, self.port) as pool:
@@ -1535,6 +1647,17 @@ class TestSSL(SocketDummyServerTestCase):
         context.load_default_certs = mock.Mock()
         context.options = 0
 
+        class MockSSLSocket:
+            def __init__(
+                self, sock: socket.socket, *args: object, **kwargs: object
+            ) -> None:
+                self._sock = sock
+
+            def close(self) -> None:
+                self._sock.close()
+
+        context.wrap_socket = MockSSLSocket
+
         with mock.patch("urllib3.util.ssl_.SSLContext", lambda *_, **__: context):
             for kwargs in [
                 {"ca_certs": "/a"},
@@ -1600,18 +1723,47 @@ class TestSSL(SocketDummyServerTestCase):
                 pool.request("GET", "/", retries=False, timeout=LONG_TIMEOUT)
         assert server_closed.wait(LONG_TIMEOUT), "The socket was not terminated"
 
-    # SecureTransport can read only small pieces of data at the moment.
-    # https://github.com/urllib3/urllib3/pull/2674
-    @notSecureTransport()
-    @pytest.mark.skipif(
-        os.environ.get("CI") == "true" and sys.implementation.name == "pypy",
-        reason="too slow to run in CI",
-    )
+    def _run_preload(self, pool: HTTPSConnectionPool, content_length: int) -> None:
+        response = pool.request("GET", "/")
+        assert len(response.data) == content_length
+
+    def _run_read_None(self, pool: HTTPSConnectionPool, content_length: int) -> None:
+        response = pool.request("GET", "/", preload_content=False)
+        assert len(response.read(None)) == content_length
+        assert response.read(None) == b""
+
+    def _run_read_amt(self, pool: HTTPSConnectionPool, content_length: int) -> None:
+        response = pool.request("GET", "/", preload_content=False)
+        assert len(response.read(content_length)) == content_length
+        assert response.read(5) == b""
+
+    def _run_read1_None(self, pool: HTTPSConnectionPool, content_length: int) -> None:
+        response = pool.request("GET", "/", preload_content=False)
+        remaining = content_length
+        while True:
+            chunk = response.read1(None)
+            if not chunk:
+                break
+            remaining -= len(chunk)
+        assert remaining == 0
+
+    def _run_read1_amt(self, pool: HTTPSConnectionPool, content_length: int) -> None:
+        response = pool.request("GET", "/", preload_content=False)
+        remaining = content_length
+        while True:
+            chunk = response.read1(content_length)
+            if not chunk:
+                break
+            remaining -= len(chunk)
+        assert remaining == 0
+
+    @pytest.mark.integration
     @pytest.mark.parametrize(
-        "preload_content,read_amt", [(True, None), (False, None), (False, 2**31)]
+        "method",
+        [_run_preload, _run_read_None, _run_read_amt, _run_read1_None, _run_read1_amt],
     )
     def test_requesting_large_resources_via_ssl(
-        self, preload_content: bool, read_amt: int | None
+        self, method: typing.Callable[[typing.Any, HTTPSConnectionPool, int], None]
     ) -> None:
         """
         Ensure that it is possible to read 2 GiB or more via an SSL
@@ -1653,9 +1805,7 @@ class TestSSL(SocketDummyServerTestCase):
         with HTTPSConnectionPool(
             self.host, self.port, ca_certs=DEFAULT_CA, retries=False
         ) as pool:
-            response = pool.request("GET", "/", preload_content=preload_content)
-            data = response.data if preload_content else response.read(read_amt)
-            assert len(data) == content_length
+            method(self, pool, content_length)
 
 
 class TestErrorWrapping(SocketDummyServerTestCase):
@@ -1830,13 +1980,16 @@ class TestHeaders(SocketDummyServerTestCase):
         body: None | bytes | io.BytesIO
         if body_type is None:
             body = None
+            expected = b"\r\n\r\n"
         elif body_type == "bytes":
             body = b"my-body"
+            expected = b"\r\n\r\nmy-body"
         elif body_type == "bytes-io":
             body = io.BytesIO(b"bytes-io-body")
             body.seek(0, 0)
+            expected = b"bytes-io-body\r\n0\r\n\r\n"
         else:
-            raise ValueError("Unknonw body type")
+            raise ValueError("Unknown body type")
 
         buffer: bytes = b""
 
@@ -1845,12 +1998,9 @@ class TestHeaders(SocketDummyServerTestCase):
             sock = listener.accept()[0]
             sock.settimeout(0)
 
-            start = time.time()
-            while time.time() - start < (LONG_TIMEOUT / 2):
-                try:
+            while expected not in buffer:
+                with contextlib.suppress(BlockingIOError):
                     buffer += sock.recv(65536)
-                except OSError:
-                    continue
 
             sock.sendall(
                 b"HTTP/1.1 200 OK\r\n"
@@ -1902,7 +2052,7 @@ class TestBrokenHeaders(SocketDummyServerTestCase):
             for record in logs:
                 if (
                     "Failed to parse headers" in record.msg
-                    and isinstance(record.args, tuple)
+                    and type(record.args) is tuple
                     and _url_from_pool(pool, "/") == record.args[0]
                 ):
                     if (
@@ -2186,11 +2336,28 @@ class TestBrokenPipe(SocketDummyServerTestCase):
 
 class TestMultipartResponse(SocketDummyServerTestCase):
     def test_multipart_assert_header_parsing_no_defects(self) -> None:
+        quit_event = threading.Event()
+
         def socket_handler(listener: socket.socket) -> None:
             for _ in range(2):
-                sock = listener.accept()[0]
-                while not sock.recv(65536).endswith(b"\r\n\r\n"):
-                    pass
+                listener.settimeout(LONG_TIMEOUT)
+
+                while True:
+                    if quit_event and quit_event.is_set():
+                        return
+                    try:
+                        sock = listener.accept()[0]
+                        break
+                    except (TimeoutError, socket.timeout):
+                        continue
+
+                sock.settimeout(LONG_TIMEOUT)
+                while True:
+                    if quit_event and quit_event.is_set():
+                        sock.close()
+                        return
+                    if sock.recv(65536).endswith(b"\r\n\r\n"):
+                        break
 
                 sock.sendall(
                     b"HTTP/1.1 404 Not Found\r\n"
@@ -2206,7 +2373,7 @@ class TestMultipartResponse(SocketDummyServerTestCase):
                 )
                 sock.close()
 
-        self._start_server(socket_handler)
+        self._start_server(socket_handler, quit_event=quit_event)
         from urllib3.connectionpool import log
 
         with mock.patch.object(log, "warning") as log_warning:
@@ -2262,19 +2429,28 @@ class TestContentFraming(SocketDummyServerTestCase):
     def test_chunked_specified(
         self, method: str, chunked: bool, body_type: str
     ) -> None:
+        quit_event = threading.Event()
         buffer = bytearray()
+        expected_bytes = b"\r\n\r\na\r\nxxxxxxxxxx\r\n0\r\n\r\n"
 
         def socket_handler(listener: socket.socket) -> None:
             nonlocal buffer
-            sock = listener.accept()[0]
-            sock.settimeout(0)
-
-            start = time.time()
-            while time.time() - start < (LONG_TIMEOUT / 2):
+            listener.settimeout(LONG_TIMEOUT)
+            while True:
+                if quit_event.is_set():
+                    return
                 try:
-                    buffer += sock.recv(65536)
-                except OSError:
+                    sock = listener.accept()[0]
+                    break
+                except (TimeoutError, socket.timeout):
                     continue
+            sock.settimeout(LONG_TIMEOUT)
+
+            while expected_bytes not in buffer:
+                if quit_event.is_set():
+                    return
+                with contextlib.suppress(BlockingIOError):
+                    buffer += sock.recv(65536)
 
             sock.sendall(
                 b"HTTP/1.1 200 OK\r\n"
@@ -2283,7 +2459,7 @@ class TestContentFraming(SocketDummyServerTestCase):
             )
             sock.close()
 
-        self._start_server(socket_handler)
+        self._start_server(socket_handler, quit_event=quit_event)
 
         body: typing.Any
         if body_type == "generator":
@@ -2313,7 +2489,7 @@ class TestContentFraming(SocketDummyServerTestCase):
         assert b"Transfer-Encoding: chunked\r\n" in sent_bytes
         assert b"User-Agent: python-urllib3/" in sent_bytes
         assert b"content-length" not in sent_bytes.lower()
-        assert b"\r\n\r\na\r\nxxxxxxxxxx\r\n0\r\n\r\n" in sent_bytes
+        assert expected_bytes in sent_bytes
 
     @pytest.mark.parametrize("method", ["POST", "PUT", "PATCH"])
     @pytest.mark.parametrize(
@@ -2321,18 +2497,44 @@ class TestContentFraming(SocketDummyServerTestCase):
     )
     def test_chunked_not_specified(self, method: str, body_type: str) -> None:
         buffer = bytearray()
+        expected_bytes: bytes
+        body: typing.Any
+
+        if body_type == "generator":
+
+            def body_generator() -> typing.Generator[bytes, None, None]:
+                yield b"x" * 10
+
+            body = body_generator()
+            should_be_chunked = True
+        elif body_type == "file":
+            body = io.BytesIO(b"x" * 10)
+            body.seek(0, 0)
+            should_be_chunked = True
+        elif body_type == "file_text":
+            body = io.StringIO("x" * 10)
+            body.seek(0, 0)
+            should_be_chunked = True
+        elif body_type == "bytearray":
+            body = bytearray(b"x" * 10)
+            should_be_chunked = False
+        else:
+            body = b"x" * 10
+            should_be_chunked = False
+
+        if should_be_chunked:
+            expected_bytes = b"\r\n\r\na\r\nxxxxxxxxxx\r\n0\r\n\r\n"
+        else:
+            expected_bytes = b"\r\n\r\nxxxxxxxxxx"
 
         def socket_handler(listener: socket.socket) -> None:
             nonlocal buffer
             sock = listener.accept()[0]
             sock.settimeout(0)
 
-            start = time.time()
-            while time.time() - start < (LONG_TIMEOUT / 2):
-                try:
+            while expected_bytes not in buffer:
+                with contextlib.suppress(BlockingIOError):
                     buffer += sock.recv(65536)
-                except OSError:
-                    continue
 
             sock.sendall(
                 b"HTTP/1.1 200 OK\r\n"
@@ -2343,33 +2545,6 @@ class TestContentFraming(SocketDummyServerTestCase):
 
         self._start_server(socket_handler)
 
-        body: typing.Any
-        if body_type == "generator":
-
-            def body_generator() -> typing.Generator[bytes, None, None]:
-                yield b"x" * 10
-
-            body = body_generator()
-            should_be_chunked = True
-
-        elif body_type == "file":
-            body = io.BytesIO(b"x" * 10)
-            body.seek(0, 0)
-            should_be_chunked = True
-
-        elif body_type == "file_text":
-            body = io.StringIO("x" * 10)
-            body.seek(0, 0)
-            should_be_chunked = True
-
-        elif body_type == "bytearray":
-            body = bytearray(b"x" * 10)
-            should_be_chunked = False
-
-        else:
-            body = b"x" * 10
-            should_be_chunked = False
-
         with HTTPConnectionPool(
             self.host, self.port, timeout=LONG_TIMEOUT, retries=False
         ) as pool:
@@ -2385,12 +2560,12 @@ class TestContentFraming(SocketDummyServerTestCase):
         if should_be_chunked:
             assert b"content-length" not in sent_bytes.lower()
             assert b"Transfer-Encoding: chunked\r\n" in sent_bytes
-            assert b"\r\n\r\na\r\nxxxxxxxxxx\r\n0\r\n\r\n" in sent_bytes
+            assert expected_bytes in sent_bytes
 
         else:
             assert b"Content-Length: 10\r\n" in sent_bytes
             assert b"transfer-encoding" not in sent_bytes.lower()
-            assert sent_bytes.endswith(b"\r\n\r\nxxxxxxxxxx")
+            assert sent_bytes.endswith(expected_bytes)
 
     @pytest.mark.parametrize(
         "header_transform",
@@ -2421,12 +2596,9 @@ class TestContentFraming(SocketDummyServerTestCase):
             sock = listener.accept()[0]
             sock.settimeout(0)
 
-            start = time.time()
-            while time.time() - start < (LONG_TIMEOUT / 2):
-                try:
+            while expected not in buffer:
+                with contextlib.suppress(BlockingIOError):
                     buffer += sock.recv(65536)
-                except OSError:
-                    continue
 
             sock.sendall(
                 b"HTTP/1.1 200 OK\r\n"
